Package: MSstatsBig
Type: Package
Title: MSstats Preprocessing for Larger than Memory Data
Version: 1.11.1
Authors@R: c(
  person("Anthony", "Wu", email = "wu.anthon@northeastern.edu", role = c("aut", "cre")),
  person("Mateusz", "Staniak", email = "mtst@mstaniak.pl", role = "aut"),
  person("Devon", "Kohler", email = "kohler.d@northeastern.edu", role = "aut")) 
Description: MSstats package provide tools for preprocessing, summarization and
    differential analysis of mass spectrometry (MS) proteomics data. Recently, 
    some MS protocols enable acquisition of data sets that result in larger than
    memory quantitative data. MSstats functions are not able to process such data.
    MSstatsBig package provides additional converter functions that enable 
    processing larger than memory data sets.
License: Artistic-2.0
Encoding: UTF-8
Imports: arrow, data.table, DBI, dplyr, MSstats, MSstatsConvert, readr,
        sparklyr, utils, stats
Suggests: testthat, mockery, knitr, rmarkdown
VignetteBuilder: knitr
biocViews: MassSpectrometry, Proteomics, Software
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/MSstatsBig
git_branch: devel
git_last_commit: 1527b08
git_last_commit_date: 2026-08-07
Repository: Bioconductor 3.24
Date/Publication: 2026-08-09
NeedsCompilation: no
Packaged: 2026-08-09 23:04:53 UTC; biocbuild
Author: Anthony Wu [aut, cre],
  Mateusz Staniak [aut],
  Devon Kohler [aut]
Maintainer: Anthony Wu <wu.anthon@northeastern.edu>
