# Generated by roxygen2: do not edit by hand

export(MSstatsAddAnnotationBig)
export(MSstatsPreprocessBig)
export(bigDIANNtoMSstatsFormat)
export(bigFragPipetoMSstatsFormat)
export(bigSpectronauttoMSstatsFormat)
importFrom(MSstats,dataProcess)
importFrom(MSstats,groupComparison)
importFrom(MSstatsConvert,MSstatsClean)
importFrom(MSstatsConvert,MSstatsImport)
importFrom(MSstatsConvert,MSstatsMakeAnnotation)
importFrom(data.table,":=")
importFrom(data.table,.SD)
importFrom(data.table,setDT)
importFrom(data.table,setnames)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,sessionInfo)
