% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_DIANN.R
\name{reduceBigDIANN}
\alias{reduceBigDIANN}
\title{Read and clean a large DIANN file in chunks}
\usage{
reduceBigDIANN(
  input_file,
  output_path,
  MBR = TRUE,
  quantificationColumn = "FragmentQuantCorrected",
  global_qvalue_cutoff = 0.01,
  qvalue_cutoff = 0.01,
  pg_qvalue_cutoff = 0.01,
  calculateAnomalyScores = FALSE,
  anomalyModelFeatures = c(),
  annotation = NULL
)
}
\arguments{
\item{input_file}{Path to the input DIANN file}

\item{output_path}{Path to the output CSV file}

\item{MBR}{Boolean, whether MBR was used}

\item{quantificationColumn}{Name of the column containing intensity values}

\item{global_qvalue_cutoff}{Global Q-value cutoff}

\item{qvalue_cutoff}{Q-value cutoff}

\item{pg_qvalue_cutoff}{Protein group Q-value cutoff}

\item{calculateAnomalyScores}{Boolean for MSstats+ Model}

\item{anomalyModelFeatures}{Character vector of features to use for MSstats+ Model}

\item{annotation}{Annotation file or data frame}
}
\value{
NULL. Writes to file.
}
\description{
Read and clean a large DIANN file in chunks
}
\keyword{internal}
