% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.writeChunkToFile}
\alias{.writeChunkToFile}
\title{Write chunk to file}
\usage{
.writeChunkToFile(input, output_path, pos)
}
\arguments{
\item{input}{Data frame}

\item{output_path}{Path to output file}

\item{pos}{Chunk position}
}
\description{
Write chunk to file
}
\keyword{internal}
