% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_DIANN.R
\name{cleanDIANNChunk}
\alias{cleanDIANNChunk}
\title{Clean a single chunk of DIANN data}
\usage{
cleanDIANNChunk(
  input,
  output_path,
  MBR,
  quantificationColumn,
  pos,
  global_qvalue_cutoff = 0.01,
  qvalue_cutoff = 0.01,
  pg_qvalue_cutoff = 0.01,
  calculateAnomalyScores = FALSE,
  anomalyModelFeatures = c(),
  annotation = NULL
)
}
\arguments{
\item{input}{Data frame chunk}

\item{output_path}{Path to output file}

\item{MBR}{Boolean, whether MBR was used}

\item{quantificationColumn}{Name of intensity column}

\item{pos}{Chunk position (1 for first chunk, >1 for subsequent)}

\item{global_qvalue_cutoff}{Global Q-value cutoff}

\item{qvalue_cutoff}{Q-value cutoff}

\item{pg_qvalue_cutoff}{Protein group Q-value cutoff}

\item{calculateAnomalyScores}{Boolean for MSstats+ Model}

\item{anomalyModelFeatures}{Character vector of features to use for MSstats+ Model}

\item{annotation}{Annotation file or data frame}
}
\description{
Clean a single chunk of DIANN data
}
\keyword{internal}
